@@ -7,26 +7,30 @@ import unittest
 import fiona
 import fiona.ogrext
 
-logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
+FIXME_WINDOWS = sys.platform.startswith("win")
+
+logging.basicConfig(stream=sys.stderr, level=logging.INFO)
 
 def test_single_file_private():
     with fiona.drivers():
-        assert fiona.ogrext._listlayers('docs/data/test_uk.shp') == ['test_uk']
+        assert fiona.ogrext._listlayers('tests/data/coutwildrnp.shp') == ['coutwildrnp']
 
 def test_single_file():
-    assert fiona.listlayers('docs/data/test_uk.shp') == ['test_uk']
+    assert fiona.listlayers('tests/data/coutwildrnp.shp') == ['coutwildrnp']
 
 def test_directory():
-    assert fiona.listlayers('docs/data') == ['test_uk']
+    assert fiona.listlayers('tests/data') == ['coutwildrnp', 'gre']
 
+@unittest.skipIf(FIXME_WINDOWS,
+                 reason="FIXME on Windows. ValueError raised. Please look into why this test isn't working.")
 def test_directory_trailing_slash():
-    assert fiona.listlayers('docs/data/') == ['test_uk']
+    assert fiona.listlayers('tests/data/') == ['coutwildrnp', 'gre']
 
 def test_zip_path():
-    assert fiona.listlayers('zip://docs/data/test_uk.zip') == ['test_uk']
+    assert fiona.listlayers('zip://tests/data/coutwildrnp.zip') == ['coutwildrnp']
 
 def test_zip_path_arch():
-    assert fiona.listlayers('/test_uk.shp', vfs='zip://docs/data/test_uk.zip') == ['test_uk']
+    assert fiona.listlayers('/coutwildrnp.shp', vfs='zip://tests/data/coutwildrnp.zip') == ['coutwildrnp']
 
 class ListLayersArgsTest(unittest.TestCase):
     def test_path(self):
